summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/widget.cpp6
-rw-r--r--src/widget_type.h2
2 files changed, 4 insertions, 4 deletions
diff --git a/src/widget_type.h b/src/widget_type.h
index e1fd92f63..c4c46ce66 100644
--- a/src/widget_type.h
+++ b/src/widget_type.h
@@ -543,7 +543,7 @@ private:
*/
class NWidgetSpacer : public NWidgetResizeBase {
public:
- NWidgetSpacer(int length, int height);
+ NWidgetSpacer(int width, int height);
void SetupSmallestSize(Window *w, bool init_array) override;
void FillNestedArray(NWidgetBase **array, uint length) override;
diff --git a/src/widget.cpp b/src/widget.cpp
index 1e3afb155..74a89eaea 100644
--- a/src/widget.cpp
+++ b/src/widget.cpp
@@ -1503,12 +1503,12 @@ void NWidgetVertical::AssignSizePosition(SizingType sizing, uint x, uint y, uint
/**
* Generic spacer widget.
* @param length Horizontal size of the spacer widget.
* @param height Vertical size of the spacer widget.
*/
-NWidgetSpacer::NWidgetSpacer(int length, int height) : NWidgetResizeBase(NWID_SPACER, 0, 0)
+NWidgetSpacer::NWidgetSpacer(int width, int height) : NWidgetResizeBase(NWID_SPACER, 0, 0)
{
- this->SetMinimalSize(length, height);
+ this->SetMinimalSize(width, height);
this->SetResize(0, 0);
}
@@ -1503,12 +1503,12 @@ void NWidgetVertical::AssignSizePosition(SizingType sizing, uint x, uint y, uint
/**
* Generic spacer widget.
- * @param length Horizontal size of the spacer widget.
+ * @param width Horizontal size of the spacer widget.
* @param height Vertical size of the spacer widget.
*/